==> cirq_unstable-0.7.0.dev20191115013934-py3-none-any.whl: cirq/google/api/v2/program.py <==
# Copyright 2019 The Cirq Developers
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from typing import TYPE_CHECKING

from cirq import devices, ops

if TYPE_CHECKING:
    import cirq


def qubit_to_proto_id(q: ops.Qid) -> str:
    """Return a proto id for a `cirq.Qid`.

    For `cirq.GridQubit`s this id `{row}_{col}` where `{row}` is the integer
    row of the grid qubit, and `{col}` is the integer column of the qubit.

    For `cirq.NamedQubit`s this id is the name.

    For `cirq.LineQubit`s this is string of the `x` attribute.
    """
    if isinstance(q, devices.GridQubit):
        return '{}_{}'.format(q.row, q.col)
    elif isinstance(q, ops.NamedQubit):
        return q.name
    elif isinstance(q, devices.LineQubit):
        return '{}'.format(q.x)
    else:
        raise ValueError('Qubits of type {} do not support proto id'.format(
            type(q)))


def grid_qubit_from_proto_id(proto_id: str) -> 'cirq.GridQubit':
    """Parse a proto id to a `cirq.GridQubit`.

    Proto ids for grid qubits are of the form `{row}_{col}` where `{row}` is
    the integer row of the grid qubit, and `{col}` is the integer column of
    the qubit.

    Args:
        proto_id: The id to convert.

    Returns:
        A `cirq.GridQubit` corresponding to the proto id.

    Raises:
        ValueError: If the string not of the correct format.
    """
    parts = proto_id.split('_')
    if len(parts) != 2:
        raise ValueError(
            'GridQubit proto id must be of the form <int>_<int> but was {}'.
            format(proto_id))
    try:
        row, col = parts
        return devices.GridQubit(row=int(row), col=int(col))
    except ValueError:
        raise ValueError(
            'GridQubit proto id must be of the form <int>_<int> but was {}'.
            format(proto_id))


def line_qubit_from_proto_id(proto_id: str) -> 'cirq.LineQubit':
    """Parse a proto id to a `cirq.LineQubit`.

    Proto ids for line qubits are integer strings representing the `x`
    attribute of the line qubit.

    Args:
        proto_id: The id to convert.

    Returns:
        A `cirq.LineQubit` corresponding to the proto id.

    Raises:
        ValueError: If the string is not an integer.
    """
    try:
        return devices.LineQubit(x=int(proto_id))
    except ValueError:
        raise ValueError(
            'Line qubit proto id must be an int but was {}'.format(proto_id))


def named_qubit_from_proto_id(proto_id: str) -> 'cirq.NamedQubit':
    """Parse a proto id to a `cirq.NamedQubit'

    This simply returns a `cirq.NamedQubit` with a name equal to `proto_id`.
    """
    return ops.NamedQubit(proto_id)

==> cirq_unstable-0.8.0.dev20200129194008-py3-none-any.whl: cirq/google/api/v2/program.py <==
# Copyright 2019 The Cirq Developers
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from typing import TYPE_CHECKING

from cirq import devices, ops

if TYPE_CHECKING:
    import cirq


def qubit_to_proto_id(q: 'cirq.Qid') -> str:
    """Return a proto id for a `cirq.Qid`.

    For `cirq.GridQubit`s this id `{row}_{col}` where `{row}` is the integer
    row of the grid qubit, and `{col}` is the integer column of the qubit.

    For `cirq.NamedQubit`s this id is the name.

    For `cirq.LineQubit`s this is string of the `x` attribute.
    """
    if isinstance(q, devices.GridQubit):
        return '{}_{}'.format(q.row, q.col)
    elif isinstance(q, ops.NamedQubit):
        return q.name
    elif isinstance(q, devices.LineQubit):
        return '{}'.format(q.x)
    else:
        raise ValueError('Qubits of type {} do not support proto id'.format(
            type(q)))


def grid_qubit_from_proto_id(proto_id: str) -> 'cirq.GridQubit':
    """Parse a proto id to a `cirq.GridQubit`.

    Proto ids for grid qubits are of the form `{row}_{col}` where `{row}` is
    the integer row of the grid qubit, and `{col}` is the integer column of
    the qubit.

    Args:
        proto_id: The id to convert.

    Returns:
        A `cirq.GridQubit` corresponding to the proto id.

    Raises:
        ValueError: If the string not of the correct format.
    """
    parts = proto_id.split('_')
    if len(parts) != 2:
        raise ValueError(
            'GridQubit proto id must be of the form <int>_<int> but was {}'.
            format(proto_id))
    try:
        row, col = parts
        return devices.GridQubit(row=int(row), col=int(col))
    except ValueError:
        raise ValueError(
            'GridQubit proto id must be of the form <int>_<int> but was {}'.
            format(proto_id))


def line_qubit_from_proto_id(proto_id: str) -> 'cirq.LineQubit':
    """Parse a proto id to a `cirq.LineQubit`.

    Proto ids for line qubits are integer strings representing the `x`
    attribute of the line qubit.

    Args:
        proto_id: The id to convert.

    Returns:
        A `cirq.LineQubit` corresponding to the proto id.

    Raises:
        ValueError: If the string is not an integer.
    """
    try:
        return devices.LineQubit(x=int(proto_id))
    except ValueError:
        raise ValueError(
            'Line qubit proto id must be an int but was {}'.format(proto_id))


def named_qubit_from_proto_id(proto_id: str) -> 'cirq.NamedQubit':
    """Parse a proto id to a `cirq.NamedQubit'

    This simply returns a `cirq.NamedQubit` with a name equal to `proto_id`.
    """
    return ops.NamedQubit(proto_id)
